==> commons-iterables-1.1.2-sources.jar: net/markenwerk/commons/iterables/ArrayIterable.java <==
/*
 * Copyright (c) 2015 Torsten Krause, Markenwerk GmbH
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.markenwerk.commons.iterables;

import java.util.Iterator;

import net.markenwerk.commons.iterators.ArrayIterator;

/**
 * An {@link ArrayIterable} is a {@link Iterable} that generates
 * {@link Iterator Iterators} that iterate over a given payload array.
 * 
 * <p>
 * Calling {@link ArrayIterable#iterator()} creates an instance of
 * {@link ArrayIterator}.
 * 
 * @param <Payload>
 *            The payload type.
 * @author Torsten Krause (tk at markenwerk dot net)
 * @since 1.0.0
 */
public final class ArrayIterable<Payload> implements Iterable<Payload> {

	private final Payload[] values;

	private final boolean removable;

	private final Payload replacement;

	/**
	 * Creates a new {@link ArrayIterable} for the given payload array.
	 * 
	 * @param values
	 *            The payload array to iterate over.
	 */
	public ArrayIterable(Payload[] values) {
		this(values, false, null);
	}

	/**
	 * Creates a new {@link ArrayIterable} for the given payload array.
	 * 
	 * @param values
	 *            The payload array to iterate over.
	 * @param replacement
	 *            The value to replace removed values with.
	 */
	public ArrayIterable(Payload[] values, Payload replacement) {
		this(values, true, replacement);
	}

	private ArrayIterable(Payload[] values, boolean removable, Payload replacement) {
		this.values = values;
		this.removable = removable;
		this.replacement = replacement;
	}

	@Override
	public Iterator<Payload> iterator() {
		return removable ? new ArrayIterator<Payload>(values, replacement) : new ArrayIterator<Payload>(values);
	}

}

==> commons-iterables-2.0.0-sources.jar: net/markenwerk/commons/iterables/ArrayIterable.java <==
/*
 * Copyright (c) 2015 Torsten Krause, Markenwerk GmbH
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.markenwerk.commons.iterables;

import java.util.Iterator;

import net.markenwerk.commons.iterators.ArrayIterator;

/**
 * An {@link ArrayIterable} is a {@link Iterable} that generates
 * {@link Iterator Iterators} that iterate over a given payload array.
 * 
 * <p>
 * Calling {@link ArrayIterable#iterator()} creates an instance of
 * {@link ArrayIterator}.
 * 
 * @param <Payload>
 *            The payload type.
 * @author Torsten Krause (tk at markenwerk dot net)
 * @since 1.0.0
 */
public final class ArrayIterable<Payload> implements Iterable<Payload> {

	private final Payload[] array;

	private final boolean removable;

	private final Payload replacement;

	/**
	 * Creates a new {@link ArrayIterable} for the given payload array.
	 * 
	 * @param array
	 *            The payload array to iterate over.
	 * 
	 * @throws IllegalArgumentException
	 *             If the given payload array is {@literal null}.
	 */
	public ArrayIterable(Payload[] array) throws IllegalArgumentException {
		this(array, false, null);
	}

	/**
	 * Creates a new {@link ArrayIterable} for the given payload array.
	 * 
	 * @param array
	 *            The payload array to iterate over.
	 * @param replacement
	 *            The value to replace removed array with.
	 * 
	 * @throws IllegalArgumentException
	 *             If the given payload array is {@literal null}.
	 */
	public ArrayIterable(Payload[] array, Payload replacement) throws IllegalArgumentException {
		this(array, true, replacement);
	}

	private ArrayIterable(Payload[] array, boolean removable, Payload replacement) throws IllegalArgumentException {
		if (null == array) {
			throw new IllegalArgumentException("array is null");
		}
		this.array = array;
		this.removable = removable;
		this.replacement = replacement;
	}

	@Override
	public ArrayIterator<Payload> iterator() {
		return removable ? new ArrayIterator<Payload>(array, replacement) : new ArrayIterator<Payload>(array);
	}

}
